@@ -29,10 +29,17 @@ if (! interface_exists(\PHPUnit\Framework\MockObject\MockObject::class)) {
 }
 
 if (! class_exists(\PHPUnit\Framework\MockObject\Builder\InvocationMocker::class)) {
-    class_alias(
-        \PHPUnit_Framework_MockObject_Builder_InvocationMocker::class,
-        \PHPUnit\Framework\MockObject\Builder\InvocationMocker::class
-    );
+    if (class_exists(\PHPUnit\Framework\MockObject\InvocationStubberImplementation::class)) {
+        class_alias(
+            \PHPUnit\Framework\MockObject\InvocationStubberImplementation::class,
+            \PHPUnit\Framework\MockObject\Builder\InvocationMocker::class
+        );
+    } else {
+        class_alias(
+            \PHPUnit_Framework_MockObject_Builder_InvocationMocker::class,
+            \PHPUnit\Framework\MockObject\Builder\InvocationMocker::class
+        );
+    }
 }
 
 if (class_exists(\PHPUnit\Framework\MockObject\Rule\MethodName::class)) {
@@ -90,6 +97,11 @@ if ($hasVersion
 }
 
 if ($hasVersion
+    && version_compare(\PHPUnit\Runner\Version::id(), '12.0.0') >= 0
+) {
+    class_alias(\phpmock\phpunit\DefaultArgumentRemoverReturnTypes120::class, \phpmock\phpunit\DefaultArgumentRemover::class);
+    class_alias(\phpmock\phpunit\MockObjectProxyReturnTypes120::class, \phpmock\phpunit\MockObjectProxy::class);
+} elseif ($hasVersion
     && version_compare(\PHPUnit\Runner\Version::id(), '10.0.0') >= 0
 ) {
     class_alias(\phpmock\phpunit\DefaultArgumentRemoverReturnTypes100::class, \phpmock\phpunit\DefaultArgumentRemover::class);
