@@ -2,6 +2,7 @@
 
 namespace phpmock\phpunit;
 
+use Closure;
 use phpmock\Deactivatable;
 use PHPUnit\Event\Test\Finished;
 use PHPUnit\Event\Test\FinishedSubscriber;
@@ -22,15 +23,22 @@ class MockDisablerPHPUnit10 implements FinishedSubscriber
      * @var Deactivatable The function mocks.
      */
     private $deactivatable;
+
+    /**
+     * @var Closure|null The callback to execute after the test.
+     */
+    private $callback;
     
     /**
      * Sets the function mocks.
      *
      * @param Deactivatable $deactivatable The function mocks.
+     * @param Closure|null $callback       The callback to execute after the test.
      */
-    public function __construct(Deactivatable $deactivatable)
+    public function __construct(Deactivatable $deactivatable, ?Closure $callback = null)
     {
         $this->deactivatable = $deactivatable;
+        $this->callback = $callback;
     }
 
     /**
@@ -39,10 +47,16 @@ class MockDisablerPHPUnit10 implements FinishedSubscriber
     public function notify(Finished $event) : void
     {
         $this->deactivatable->disable();
+        if ($this->callback !== null) {
+            ($this->callback)($this);
+        }
     }
 
     public function endTest(): void
     {
         $this->deactivatable->disable();
+        if ($this->callback !== null) {
+            ($this->callback)($this);
+        }
     }
 }
