@@ -7,8 +7,10 @@ use phpmock\integration\MockDelegateFunctionBuilder;
 use phpmock\MockBuilder;
 use phpmock\Deactivatable;
 use PHPUnit\Event\Facade;
+use PHPUnit\Event\Test\Finished;
 use PHPUnit\Framework\MockObject\MockObject;
 use ReflectionClass;
+use ReflectionMethod;
 use ReflectionProperty;
 use SebastianBergmann\Template\Template;
 
@@ -66,10 +68,12 @@ trait PHPMock
         $delegateBuilder->build($name);
 
         $builder = $this->getMockBuilder($delegateBuilder->getFullyQualifiedClassName());
-        if (is_callable([$builder, 'addMethods'])) {
-            $builder->addMethods([$name]);
+        if (is_callable([$builder, 'onlyMethods'])) {
+            $builder->onlyMethods([MockDelegateFunctionBuilder::METHOD, $name]);
+        } elseif (is_callable([$builder, 'setMethods'])) {
+            $builder->setMethods([MockDelegateFunctionBuilder::METHOD, $name]);
         }
-        $mock = $builder->getMockForAbstractClass();
+        $mock = $builder->getMock();
         $this->addMatcher($mock, $name);
 
         $functionMockBuilder = new MockBuilder();
@@ -115,8 +119,32 @@ trait PHPMock
             $property->setAccessible(true);
             $property->setValue($facade, false);
 
+            $method = new ReflectionMethod($facade, 'deferredDispatcher');
+            $method->setAccessible(true);
+            $dispatcher = $method->invoke($facade);
+
+            $propDispatcher = new ReflectionProperty($dispatcher, 'dispatcher');
+            $propDispatcher->setAccessible(true);
+            $directDispatcher = $propDispatcher->getValue($dispatcher);
+
+            $propSubscribers = new ReflectionProperty($directDispatcher, 'subscribers');
+            $propSubscribers->setAccessible(true);
+
             $facade->registerSubscriber(
-                new MockDisabler($deactivatable)
+                new MockDisabler(
+                    $deactivatable,
+                    static function (MockDisabler $original) use ($directDispatcher, $propSubscribers) {
+                        $subscribers = $propSubscribers->getValue($directDispatcher);
+
+                        foreach ($subscribers[Finished::class] as $key => $subscriber) {
+                            if ($original === $subscriber) {
+                                unset($subscribers[Finished::class][$key]);
+                            }
+                        }
+
+                        $propSubscribers->setValue($directDispatcher, $subscribers);
+                    }
+                )
             );
 
             $property->setValue($facade, true);
@@ -125,7 +153,9 @@ trait PHPMock
         }
 
         $result = $this->getTestResultObject();
-        $result->addListener(new MockDisabler($deactivatable));
+        $result->addListener(new MockDisabler($deactivatable, static function (MockDisabler $listener) use ($result) {
+            $result->removeListener($listener);
+        }));
     }
 
     /**
@@ -199,8 +229,9 @@ trait PHPMock
         }
 
         $mockMethodClasses = [
-            'PHPUnit\\Framework\\MockObject\\Generator\\MockMethod',
-            'PHPUnit\\Framework\\MockObject\\MockMethod',
+            'PHPUnit\\Framework\\MockObject\\Generator\\DoubledMethod', // PHPUnit 12
+            'PHPUnit\\Framework\\MockObject\\Generator\\MockMethod',    // PHPUnit 10-11
+            'PHPUnit\\Framework\\MockObject\\MockMethod',               // PHPUnit 9
         ];
 
         foreach ($mockMethodClasses as $mockMethodClass) {
